@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -69,6 +69,7 @@ import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.fields.ResponseFields;
+import com.openexchange.config.ConfigurationService;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.multiple.MultipleHandler;
@@ -88,13 +89,19 @@ import com.openexchange.tools.session.ServerSession;
  */
 public class PublicationMultipleHandler implements MultipleHandler {
 
+    private static final String PROPERTY_USE_OTHER_DOMAIN = "com.openexchange.publish.domain";
+    private static final String PROPERTY_USE_OTHER_SUBDOMAIN = "com.openexchange.publish.subdomain";
+
     private final PublicationTargetDiscoveryService discovery;
 
     private final Map<String, EntityType> entities;
-
-    public PublicationMultipleHandler(final PublicationTargetDiscoveryService discovery, final Map<String, EntityType> entities) {
+    
+    private ConfigurationService config;
+    
+    public PublicationMultipleHandler(final PublicationTargetDiscoveryService discovery, final Map<String, EntityType> entities, ConfigurationService config) {
         this.discovery = discovery;
         this.entities = entities;
+        this.config = config;
     }
 
     public void close() {
@@ -130,7 +137,7 @@ public class PublicationMultipleHandler implements MultipleHandler {
             } else if (action.equals("get")) {
                 return loadPublication(request, session);
             } else if (action.equals("all")) {
-                return loadAllPublicationsForEntity(request, session);
+                return loadAllPublications(request, session);
             } else if (action.equals("list")) {
                 return listPublications(request, session);
             } else {
@@ -168,19 +175,37 @@ public class PublicationMultipleHandler implements MultipleHandler {
         return createList(publications, basicColumns, dynamicColumns, dynamicColumnOrder);
     }
 
-    private Object loadAllPublicationsForEntity(final JSONObject request, final ServerSession session) throws PublicationJSONException, JSONException, PublicationException {
-        if (!request.has("entityModule")) {
-            throw MISSING_PARAMETER.create("entityModule");
+    private Object loadAllPublications(final JSONObject request, final ServerSession session) throws PublicationJSONException, JSONException, PublicationException {
+    	final Context context = session.getContext();  
+    	final int userId = session.getUserId();
+    	boolean containsFolderOrId = false;
+    	
+    	if (request.has("folder") || request.has("id")) {
+    		if (!request.has("entityModule")) {
+    			throw MISSING_PARAMETER.create("entityModule");
+    		}
+    		containsFolderOrId = true;
+        } 
+    	
+    	String module = null;    	
+    	if (request.has("entityModule")) {
+    		module = request.optString("entityModule");        	
+    	}
+        
+        // Check if request contains folder attribute. If not assume a request for all publications of the session user.
+    	// If module is set in this case, fetch all publications of a user in that module.
+        final List<Publication> publications;
+        if (containsFolderOrId) {
+        	final EntityType entityType = entities.get(module);
+            if (null == entityType) {
+                throw UNKOWN_ENTITY_MODULE.create(module);
+            }
+            final String entityId = entityType.toEntityID(request);
+        	publications = loadAllPublicationsForEntity(context, entityId, module);
+        } else {
+        	publications = loadAllPublicationsForUser(context, userId, module);
         }
-        final String module = request.optString("entityModule");
-        final EntityType entityType = entities.get(module);
-        if (null == entityType) {
-            throw UNKOWN_ENTITY_MODULE.create(module);
-        }
-        final String entityId = entityType.toEntityID(request);
-        final Context context = session.getContext();
-        final List<Publication> publications = loadAllPublicationsForEntity(context, entityId, module);
-
+        
         final String[] basicColumns = getBasicColumns(request);
         final Map<String, String[]> dynamicColumns = getDynamicColumns(request);
         final List<String> dynamicColumnOrder = getDynamicColumnOrder(request);
@@ -230,10 +255,34 @@ public class PublicationMultipleHandler implements MultipleHandler {
     private String[] getBasicColumns(final JSONObject request) {
         final String columns = request.optString("columns");
         if (columns == null || columns.equals("")) {
-            return new String[] { "id", "entityId", "entityModule", "target" };
+            return new String[] { "id", "entity", "entityModule", "target", "enabled" };
         }
         return columns.split("\\s*,\\s*");
     }
+    
+    private List<Publication> loadAllPublicationsForUser(final Context context, int userId, String module) throws PublicationException {
+    	final List<Publication> publications = new LinkedList<Publication>();
+    	final Collection<PublicationTarget> targets = discovery.listTargets();
+        
+        for (final PublicationTarget target : targets) {
+        	Collection<Publication> allPublicationsForUser = null;
+        	
+        	if (module == null) {
+        		final PublicationService publicationService = target.getPublicationService();
+        		allPublicationsForUser = publicationService.getAllPublications(context, userId, target.getModule());
+        	} else {
+        		if (target.isResponsibleFor(module)) {
+        			final PublicationService publicationService = target.getPublicationService();
+        			allPublicationsForUser = publicationService.getAllPublications(context, userId, module);        			
+        		}        		
+        	}
+        	if (allPublicationsForUser != null) {
+                publications.addAll(allPublicationsForUser);
+        	} 
+        }
+        
+        return publications;
+    }
 
     private List<Publication> loadAllPublicationsForEntity(final Context context, final String entityId, final String module) throws PublicationException {
         final List<Publication> publications = new LinkedList<Publication>();
@@ -261,13 +310,35 @@ public class PublicationMultipleHandler implements MultipleHandler {
     private String getURLPrefix(JSONObject request, Publication publication) {
         String hostname = Hostname.getInstance().getHostname(publication);
         String serverURL = request.optString("__serverURL");
+        String protocol = "https://";
         if(hostname != null) {
             if(serverURL == null || serverURL.startsWith("https")) {
-                return "https://"+hostname;
+                protocol = "https://";
+            } else {
+                protocol = "http://";
+            }
+        } else if (serverURL != null ){
+            hostname = serverURL.substring(serverURL.indexOf("://")+3);
+            if(serverURL.startsWith("https")) {
+                protocol = "https://";
+            } else {
+                protocol = "http://";
             }
-            return "http://"+hostname;
         }
-        return serverURL;
+        
+        
+        String otherDomain = config.getProperty(PROPERTY_USE_OTHER_DOMAIN);
+        String separateSubdomain = config.getProperty(PROPERTY_USE_OTHER_SUBDOMAIN);
+        
+        if(otherDomain != null){
+            return protocol + otherDomain;
+        }
+        
+        if(separateSubdomain != null){
+            return protocol + separateSubdomain + "." + hostname;
+        }
+        
+        return protocol+hostname;
     }
 
     private Publication loadPublication(final int id, final Context context, final String target) throws AbstractOXException {
