@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,6 +54,7 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.MultipleAdapterServlet;
 import com.openexchange.multiple.MultipleHandler;
+import com.openexchange.tools.servlet.http.Tools;
 import com.openexchange.tools.session.ServerSession;
 
 /**
@@ -65,10 +66,12 @@ public class PublicationServlet extends MultipleAdapterServlet {
 
     private static PublicationMultipleHandlerFactory multipleFactory;
 
+	
     public static void setFactory(PublicationMultipleHandlerFactory factory) {
         multipleFactory = factory;
     }
 
+
     @Override
     protected MultipleHandler createMultipleHandler() {
         return multipleFactory.createMultipleHandler();
@@ -92,7 +95,7 @@ public class PublicationServlet extends MultipleAdapterServlet {
     }
     
     protected String getServerURL(HttpServletRequest req) {
-        String protocol = req.isSecure() ? "https://" : "http://";
+        String protocol = Tools.getProtocol(req);
         return protocol + req.getServerName();
     }
 
