@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -47,15 +47,16 @@
  *
  */
 
-
 package com.openexchange.publish.json.osgi;
 
+import java.util.ArrayList;
 import java.util.LinkedList;
 import java.util.List;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.osgi.framework.ServiceRegistration;
 import org.osgi.service.http.HttpService;
+import com.openexchange.config.ConfigurationService;
 import com.openexchange.exceptions.osgi.ComponentRegistration;
 import com.openexchange.multiple.MultipleHandlerFactoryService;
 import com.openexchange.publish.PublicationTargetDiscoveryService;
@@ -66,22 +67,21 @@ import com.openexchange.publish.json.PublicationTargetMultipleHandlerFactory;
 import com.openexchange.publish.json.PublicationTargetServlet;
 import com.openexchange.publish.json.types.EntityMap;
 import com.openexchange.server.osgiservice.DeferredActivator;
+import com.openexchange.tools.service.SessionServletRegistration;
 
 public class ServletActivator extends DeferredActivator {
 
-    private static final Log LOG = LogFactory.getLog(ServletActivator.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ServletActivator.class));
 
     private static final String TARGET_ALIAS = "ajax/publicationTargets";
     private static final String PUB_ALIAS = "ajax/publications";
 
-    private static final Class<?>[] NEEDED_SERVICES = { HttpService.class, PublicationTargetDiscoveryService.class };
+    private static final Class<?>[] NEEDED_SERVICES = { HttpService.class, PublicationTargetDiscoveryService.class, ConfigurationService.class };
 
     private ComponentRegistration componentRegistration;
 
-    private PublicationTargetServlet targetServlet;
-
-    private PublicationServlet pubServlet;
-
+    List<SessionServletRegistration> servletRegistrations = new ArrayList<SessionServletRegistration>(2);
+    
     private List<ServiceRegistration> serviceRegistrations = new LinkedList<ServiceRegistration>();
     
     @Override
@@ -101,24 +101,25 @@ public class ServletActivator extends DeferredActivator {
             return;
         }
         
-        PublicationMultipleHandlerFactory publicationHandlerFactory = new PublicationMultipleHandlerFactory(discovery, new EntityMap());
+        ConfigurationService config = getService(ConfigurationService.class);
+        if(config == null){
+        	return;
+        }
+        
+        PublicationMultipleHandlerFactory publicationHandlerFactory = new PublicationMultipleHandlerFactory(discovery, new EntityMap(), config);
         PublicationTargetMultipleHandlerFactory publicationTargetHandlerFactory = new PublicationTargetMultipleHandlerFactory(discovery);
         
         serviceRegistrations.add(context.registerService(MultipleHandlerFactoryService.class.getName(), publicationHandlerFactory, null));
         serviceRegistrations.add(context.registerService(MultipleHandlerFactoryService.class.getName(), publicationTargetHandlerFactory, null));
         
-        
         PublicationServlet.setFactory(publicationHandlerFactory);
         PublicationTargetServlet.setFactory(publicationTargetHandlerFactory);
         
-        final HttpService httpService = getService(HttpService.class);
-        try {
-            httpService.registerServlet(TARGET_ALIAS, (targetServlet = new PublicationTargetServlet()), null, null);
-            LOG.info(PublicationTargetServlet.class.getName() + " successfully re-registered.");
-            httpService.registerServlet(PUB_ALIAS, (pubServlet = new PublicationServlet()), null, null);
-            LOG.info(PublicationServlet.class.getName() + " successfully re-registered.");
-        } catch (final Exception e) {
-            LOG.error(e.getMessage(), e);
+        servletRegistrations.add(new SessionServletRegistration(context, new PublicationTargetServlet(), TARGET_ALIAS));
+        servletRegistrations.add(new SessionServletRegistration(context, new PublicationServlet(), PUB_ALIAS));
+        
+        for (SessionServletRegistration reg : servletRegistrations) {
+            reg.open();
         }
     }
 
@@ -136,15 +137,11 @@ public class ServletActivator extends DeferredActivator {
         }
         serviceRegistrations.clear();
         
-        final HttpService httpService = getService(HttpService.class);
-        if (httpService != null && targetServlet != null) {
-            httpService.unregister(TARGET_ALIAS);
-            targetServlet = null;
-            LOG.info(PublicationTargetServlet.class.getName() + " unregistered.");
-            httpService.unregister(PUB_ALIAS);
-            pubServlet = null;
-            LOG.info(PublicationServlet.class.getName() + " unregistered.");
+        for (SessionServletRegistration reg : servletRegistrations) {
+            reg.close();
         }
+        servletRegistrations.clear();
+
     }
 
     @Override
