@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,6 +54,7 @@ import org.osgi.framework.BundleActivator;
 import org.osgi.framework.BundleContext;
 import org.osgi.util.tracker.ServiceTracker;
 import com.openexchange.i18n.I18nService;
+import com.openexchange.publish.json.Hostname;
 
 /**
  * Starts the service tracker for the dynamic services like {@link I18nService}.
@@ -71,6 +72,7 @@ public class TrackerActivator implements BundleActivator {
     public void start(final BundleContext context) throws Exception {
         trackers = new Stack<ServiceTracker>();
         trackers.add(new ServiceTracker(context, I18nService.class.getName(), new I18nCustomizer(context)));
+        trackers.add(new HostnameServiceTracker(context, Hostname.getInstance()));
         for (final ServiceTracker tracker : trackers) {
             tracker.open();
         }
