@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -107,6 +107,8 @@ public class PublicationParserTest extends TestCase {
         
         object.put("com.openexchange.publish.test", config);
     
+        object.put("enabled", false);
+        
     }
     
     public void testParse() throws JSONException, PublicationException, PublicationJSONException {
@@ -124,5 +126,9 @@ public class PublicationParserTest extends TestCase {
         
         assertNotNull("config was null", config);
         assertEquals("siteName was wrong", "publication", config.get("siteName"));
+
+        assertEquals("enabled was wrong", true, publication.containsEnabled());
+        assertEquals("enabled was wrong", false, publication.isEnabled());
+    
     }
 }
